
/**
 * Canvas containing sprites
 * 
 * @author JP Vergara
 * @version 29 April 2013
 */

import java.awt.*;
import java.awt.event.*;
import java.awt.image.*;
import java.io.*;
import javax.imageio.ImageIO;
import java.util.HashMap;
import java.util.Collection;

public class GameCanvas extends Canvas
{
   private HashMap<String,Sprite> images;
   private BufferedImage bg = null;
   private int score;
   private int scoreX = 850;  // score coordinates
   private int scoreY = 25;

   public GameCanvas()
   {
      setBGImage( "background.png" );
      images = new HashMap<String,Sprite>();
      addSprites();
      addListener();
      animate();
   }

   private void addSprites()
   {
      addSprite( new Sprite("f16.png", "ship", 900, 50, 40, 30, -10, 0, this) );
      addSprite( new Tank("tank1", 100, 450, 40, 30, 10, 0, this) );
      addSprite( new Tank("tank2", 150, 500, 40, 30, 5, 0, this) );
      addSprite( new Tank("tank3", 50, 550, 40, 30, 15, 0, this) );
   }

   private void addListener()
   {
      final GameCanvas thisCanvas = this; // use thisCanvas for context
      MouseAdapter m = new MouseAdapter()
      {
         public void mousePressed( MouseEvent me )
	     {
	       Sprite s = getSprite("ship");
           addSprite( new Bomb( "bomb", s.getX(), s.getY(),
	                          20, 20, 0, 10, thisCanvas) );
	     }
      };
      addMouseListener(m);
   }

   private void setBGImage( String fn )
   {
      try
      {
         bg = ImageIO.read(new FileInputStream( fn ));
      }
      catch(IOException e)
      {
         System.out.println("background file not found");
      }
   }

   private void animate()
   {
      Thread t = new Thread()
      {
         public void run()
	 {
	    while (true)
	    {
               try { Thread.sleep( 100 ); } catch(Exception e) {}
               for( Sprite s: images.values() )
	       {
	          s.move();
	       }
	       int count = 0;
               Sprite[] sprites = new Sprite[images.size()];
               sprites = images.values().toArray(sprites);
               int length = sprites.length;
//               for( Sprite s: images.values() )
//	         for( Sprite t: images.values() )
               for( int i = 0; i < length; i++)
                  for( int j = i+1; j < length; j++)
		  {
                     Sprite s = sprites[i];
                     Sprite t = sprites[j];
		     // if ( s != t )
		     if ( s.isActive() && t.isActive() )
		     {
		        if (s.collidesWith(t))
                        {
			   s.collided(t);
			   t.collided(s);
                        }
		     }
		  }
	       repaint();
            }
	 }
      };
      t.start();
   }

   private void addSprite( Sprite s )
   {
      images.put( s.getName(), s );
   }

   private Sprite getSprite( String name )
   {
      Sprite s = images.get(name);
      return s;
   }

   public void draw( Graphics g )
   {
      g.drawImage( bg, 0, 0, this.getWidth(), this.getHeight(), null );
      for( Sprite s: images.values() )
      {
         if (s.isActive())
            g.drawImage( s.getImage(), s.getX(), s.getY(),
	              s.getWidth(), s.getHeight(), null );
      }
      g.drawString( "Score:"+score, scoreX, scoreY);
   }
   
   public void update( Graphics g )
   {
       paint( g );
   }

   private Image buff = null;
   public void paint( Graphics g )
   {
     if (buff == null)
     {
        buff = createImage( this.getWidth(), this.getHeight() );
     }
     else
     {
        draw( buff.getGraphics() );
     }
     g.drawImage( buff, 0, 0, null );
   }

   public void setScore( int s )
   {
      score = s;
   }

   public int getScore()
   {
      return score;
   }
}

