
/**
 * Class for bank (savings) accounts supporting deposit,
 * withdraw, balance inquiry, and interest.
 * 
 * @author JP Vergara 
 * @version 1.0
 */
public class SavingsAccount
{
    // Each bank accountobject stores a balance
    private double balance;
    // Savings accounts earn interest, so we need
    // an interest rate
    private double interestRate;
    

    /**
     * Constructor for objects of class SavingsAccount
     */
    public SavingsAccount()
    {
        balance = 0;
        interestRate = 1.0;
    }

    /**
     * Constructor for objects of class SavingsAccount,
     * where a rate is specified
     * 
     * @param arate  interest rate that applies to this account
     */
    public SavingsAccount( double aRate )
    {
        balance = 0;
        interestRate = aRate;
    }

    /**
     * Deposits some amount into the account
     * 
     * @param amount  amount to be deposited
     */
    public void deposit( double amount )
    {
        balance = balance + amount;
    }

    /**
     * Withdraws some amount from the account
     * 
     * @param amount  amount to be withdrawn
     */
    public void withdraw( double amount )
    {
        if ( amount <= balance )
        {
            balance = balance - amount;
        }
        else
        {
            System.out.println( "Insufficient balance" );
        }
    }

    /**
     * Get the current balance
     * 
     * @return  current balance 
     */
    public double getBalance( )
    {
        return balance;
    }

    /**
     * Adds interest based on the rate
     * 
     */
    public void addInterest()
    {
        double interest = balance*interestRate/100;
        balance = balance + interest;
        // or, deposit( interest );
    }

}
