
/**
 * Class for car objects storing gas level and odometer info.
 * 
 * @author  JP Vergara
 * @version 1.0
 */
public class Car
{
    private double gasLeft;
    private int distanceTravelled;
    private double efficiency;

    /**
     * Constructor for objects of class Car
     */
    public Car()
    {
        distanceTravelled = 0;
        gasLeft = 15.00;       // fill the tank up upfront
        efficiency = 25.0;     // start with 25 miles per gallon
    }

    /**
     * Drive the car some distance in miles
     * 
     * @param  miles   distance to drive
     */
    public void drive( int miles )
    {
        double gasNeeded = miles/efficiency;
        distanceTravelled = distanceTravelled + miles;
        gasLeft = gasLeft - gasNeeded;
    }

    /**
     * Load gas into the car
     * 
     * @param  gallons amount gas to be loaded in tank
     */
    public void loadGas( double gallons )
    {
        gasLeft = gasLeft + gallons;
    }

    /**
     * Set the efficiency of the car
     * 
     * @param  newEff  the updated efficiency of the car
     */
    public void setEfficiency( double newEff )
    {
        efficiency = newEff;
    }

    /**
     * Returns the amount of gas left in the car's tank
     * 
     * @return amount of gas left 
     */
    public double getGasLeft()
    {
        return gasLeft;
    }

    /**
     * Returns the odometer reading
     * 
     * @return distance travelled 
     */
    public int getOdometerReading()
    {
        return distanceTravelled;
    }

    /**
     * Prints gas left and distance travelled
     */
    
    public void printCarState()
    {
        System.out.print( "The car has driven " );
        System.out.print( distanceTravelled );
        System.out.println(" miles," ); 
        System.out.print( "and has " );
        System.out.print( gasLeft );
        System.out.println(" gallons left in its tank." ); 
    }
    
}
